@@ -18,17 +18,20 @@ import json
 import logging
 import os
 from datetime import datetime, timezone
-from typing import Dict, List
+from typing import Dict, List, Final
 
 from load_shedding.providers import eskom
 from load_shedding.providers.eskom import Province, Stage, Suburb, Provider, ProviderError
 
+CACHE_TTL: Final = 86400
+
 
 class ScheduleError(Exception):
     pass
 
 
 def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage: Stage = None, cached: bool = True) -> List: # Dict[Stage, list]:
+    now = datetime.now(timezone.utc)
     try:
         os.makedirs('.cache')
     except OSError as e:
@@ -48,18 +51,22 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
     cached_schedules = {}
     cached_schedule = []
     try:
-        tz = timezone.utc
         cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
         with open(cache_file, "r") as cache:
-            cached_schedules = json.loads(cache.read(), object_pairs_hook=lambda pairs: {
-                Stage(int(k)).value: v for k, v in pairs
-            })
-            cached_schedule = cached_schedules.get(stage.value, [])
+            for k, v in json.loads(cache.read()).items():
+                cached_schedules[Stage(int(k)).value] = v
+
+            cached_schedule = cached_schedules.get(stage.value, {})
+
+        if not isinstance(cached_schedule, dict) or len(cached_schedule) == 0:
+            """ Upgrade from previous list """
+            cached = False
 
         if cached and cached_schedule:
-            first = datetime.fromisoformat(cached_schedule[0][0])
-            if first >= datetime.now(tz):
-                return cached_schedule
+            updated_at = datetime.fromisoformat(cached_schedule.get("updated_at", None))
+
+            if (now - updated_at).seconds < CACHE_TTL:
+                return cached_schedule.get("schedule", {})
     except FileNotFoundError as e:
         logging.log(logging.ERROR, "Unable to get schedule from cache. {e}".format(e=e))
 
@@ -73,7 +80,10 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
     else:
         cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
         with open(cache_file, "w") as cache:
-            cached_schedules[stage.value] = schedule
+            cached_schedules[stage.value] = {
+                "updated_at": str(now),
+                "schedule": schedule,
+            }
             cache.write(json.dumps(cached_schedules))
         return schedule
 
