@@ -38,7 +38,7 @@ class AreaInfo:
         return str(self.suburb)
 
     def __repr__(self):
-        return self.suburb, self.municipality, self.province
+        return f"AreaInfo({self.suburb}, {self.municipality}, {self.province})"
 
 
 class Suburb(Suburb):
@@ -53,7 +53,7 @@ class Suburb(Suburb):
         return str(self.name)
 
     def __repr__(self):
-        return self.name, self.municipality, self.province
+        return f"Suburb({self.id}, {self.name}, {self.municipality}, {self.province})"
 
 
 class Municipality(Municipality):
@@ -68,7 +68,7 @@ class Municipality(Municipality):
         return str(self.name)
 
     def __repr__(self):
-        return self.name
+        return f"Municipality({self.id}, {self.name}"
 
 
 # TODO: Improve error handling when Eskom responds with an error.
