@@ -32,7 +32,7 @@ class Suburb:
         return self.name
 
     def __repr__(self):
-        return self.id, self.name, self.municipality, self.province
+        return f"Suburb({self.id}, {self.name}, {self.municipality}, {self.province})"
 
 
 class Municipality:
@@ -44,7 +44,7 @@ class Municipality:
         return self.name
 
     def __repr__(self):
-        return self.id, self.name
+        return f"Municipality({self.id}, {self.name}"
 
 
 class Province(Enum):
